Stan Math Library: stan::math::promote_scalar_struct< T, Eigen::Matrix< S,-1, 1 > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
stan::math::promote_scalar_struct< T, Eigen::Matrix< S,-1, 1 > > Struct Template Reference

Struct to hold static function for promoting underlying scalar types. More...

`#include <promote_scalar.hpp>`

## Static Public Member Functions
static Eigen::Matrix< typename promote_scalar_type< T, S >::type,-1, 1 > | apply (const Eigen::Matrix< S,-1, 1 > &x)
| Return the row vector consisting of the recursive promotion of the elements of the input row vector to the scalar type specified by the return template parameter. More...

## Detailed Description

### template<typename T, typename S>
struct stan::math::promote_scalar_struct< T, Eigen::Matrix< S,-1, 1 > >

Struct to hold static function for promoting underlying scalar types.

This specialization is for Eigen row vector inputs.

Template Parameters

  T | return scalar type
  S | input matrix scalar type for static nested function, which must have a scalar type assignable to T

Definition at line 79 of file promote_scalar.hpp.

## Member Function Documentation

template<typename T , typename S >

static Eigen::Matrix<typename promote_scalar_type<T, S>::type, -1, 1> stan::math::promote_scalar_struct< T, Eigen::Matrix< S,-1, 1 > >::apply | ( | const Eigen::Matrix< S,-1, 1 > & | x | ) |
| inlinestatic

Return the row vector consisting of the recursive promotion of the elements of the input row vector to the scalar type specified by the return template parameter.

Parameters

  x | input row vector.

Returns
  row vector with values promoted from input vector.

Definition at line 89 of file promote_scalar.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/promote_scalar.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.